==> veracrypt_1.17.orig.tar.bz2: src/Format/Resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Format.rc
//
#define IDR_FORMAT_TLB                  1
#define IDD_VOL_CREATION_WIZARD_DLG     101
#define IDD_CIPHER_PAGE_DLG             102
#define IDD_SIZE_PAGE_DLG               103
#define IDD_PASSWORD_PAGE_DLG           104
#define IDD_VOLUME_LOCATION_PAGE_DLG    105
#define IDD_FORMAT_PAGE_DLG             106
#define IDD_INTRO_PAGE_DLG              107
#define IDD_INFO_PAGE_DLG               108
#define IDD_HIDVOL_HOST_FILL_PAGE_DLG   109
#define IDD_HIDDEN_VOL_WIZARD_MODE_PAGE_DLG 110
#define IDD_PASSWORD_ENTRY_PAGE_DLG     111
#define IDS_UACSTRING_FMT               112
#define IDD_VOLUME_TYPE_PAGE_DLG        113
#define IDR_FORMAT_RSRC_HEADER          114
#define IDD_SYSENC_SPAN_PAGE_DLG        115
#define IDB_WIZARD                      116
#define IDD_SYSENC_RESCUE_DISK_CREATION_DLG 117
#define IDD_SYSENC_COLLECTING_RANDOM_DATA_DLG 118
#define IDD_SYSENC_MULTI_BOOT_MODE_PAGE_DLG 119
#define IDD_SYSENC_RESCUE_DISK_BURN_PAGE_DLG 120
#define IDD_SYSENC_WIPE_MODE_PAGE_DLG   121
#define IDD_INPLACE_ENCRYPTION_PAGE_DLG 122
#define IDD_SYSENC_KEYS_GEN_PAGE_DLG    123
#define IDD_UNIVERSAL_DUAL_CHOICE_PAGE_DLG 124
#define IDD_SYSENC_DRIVE_ANALYSIS_PAGE_DLG 125
#define IDD_SYSENC_TYPE_PAGE_DLG        126
#define IDD_SYSENC_HIDDEN_OS_REQ_CHECK_PAGE_DLG 127
#define IDD_DEVICE_WIPE_PAGE_DLG        128
#define IDD_DEVICE_WIPE_MODE_PAGE_DLG   129
#define IDD_DEVICE_TRANSFORM_MODE_DLG   130
#define IDD_EXPANDED_LIST_SELECT_PAGE_DLG 131
#define IDD_DRIVE_LETTER_SELECTION_PAGE 132
#define IDD_PIM_PAGE_DLG                133
#define IDC_BOX_TITLE                   1000
#define IDC_RESCUE_DISK_ISO_PATH        1001
#define IDC_COMBO_BOX                   1002
#define IDC_BOX_HELP                    1003
#define IDC_PASSWORD                    1004
#define IDC_BROWSE                      1005
#define IDC_BOX_HELP2                   1006
#define IDC_COMBO_BOX_HASH              1007
#define IDC_COMBO_BOX_HASH_ALGO         1008
#define IDC_SPACE_LEFT                  1009
#define IDC_VERIFY                      1010
#define IDC_KB                          1011
#define IDC_NO_HISTORY                  1012
#define IDC_MB                          1013
#define IDC_PROGRESS_BAR                1014
#define IDC_GB                          1015
#define IDC_ABORT_BUTTON                1016
#define IDC_HEADER_KEY                  1017
#define IDC_LIST_BOX                    1018
#define IDC_DISK_KEY                    1019
#define IDC_RANDOM_BYTES                1020
#define IDC_CIPHER_TEST                 1021
#define IDC_BENCHMARK                   1022
#define IDC_QUICKFORMAT                 1023
#define IDC_BYTESWRITTEN                1024
#define IDC_WRITESPEED                  1025
#define IDC_KEY_FILES                   1026
#define IDC_TIMEREMAIN                  1027
#define IDC_CLUSTERSIZE                 1028
#define IDC_FILESYS                     1029
#define IDC_SHOW_KEYS                   1030
#define IDC_STD_VOL                     1031
#define IDC_HIDDEN_VOL                  1032
#define IDC_HIDDEN_VOL_HELP             1033
#define IDC_OPEN_OUTER_VOLUME           1034
#define IDC_HIDVOL_WIZ_MODE_FULL        1035
#define IDC_HIDVOL_WIZ_MODE_DIRECT      1036
#define IDC_PASSWORD_DIRECT             1037
#define IDC_SIZEBOX                     1038
#define IDC_SELECT_VOLUME_LOCATION      1039
#define IDC_NEXT                        1040
#define IDC_PREV                        1041
#define IDT_ENCRYPTION_ALGO             1042
#define IDT_HASH_ALGO                   1043
#define IDT_FORMAT_OPTIONS              1044
#define IDT_FILESYSTEM                  1045
#define IDT_CLUSTER                     1046
#define IDT_RANDOM_POOL                 1047
#define IDT_HEADER_KEY                  1048
#define IDT_MASTER_KEY                  1049
#define IDT_DONE                        1050
#define IDT_SPEED                       1051
#define IDT_LEFT                        1052
#define IDT_CONFIRM                     1053
#define IDT_PASSWORD                    1054
#define IDC_SHOW_PASSWORD_SINGLE        1055
#define IDC_SHOW_PASSWORD               1056
#define IDC_LINK_MORE_INFO_ABOUT_CIPHER 1057
#define IDC_LINK_HASH_INFO              1058
#define IDC_POS_BOX                     1059
#define IDC_BITMAP_WIZARD               1060
#define IDC_FILE_CONTAINER              1061
#define IDC_NONSYS_DEVICE               1062
#define IDC_SYS_DEVICE                  1063
#define IDT_FILE_CONTAINER              1064
#define IDT_NON_SYS_DEVICE              1065
#define IDT_SYS_DEVICE                  1066
#define IDC_WHOLE_SYS_DRIVE             1067
#define IDC_SYS_PARTITION               1068
#define IDT_WHOLE_SYS_DRIVE             1069
#define IDT_SYS_PARTITION               1070
#define IDT_RESCUE_DISK_INFO            1071
#define IDC_MORE_INFO                   1072
#define IDC_MORE_INFO_ON_SYS_ENCRYPTION 1073
#define IDT_COLLECTING_RANDOM_DATA_NOTE 1074
#define IDC_MORE_INFO_ON_CONTAINERS     1075
#define IDC_SINGLE_BOOT                 1076
#define IDC_MULTI_BOOT                  1077
#define IDT_MULTI_BOOT                  1078
#define IDT_SINGLE_BOOT                 1079
#define IDC_SYS_POOL_CONTENTS           1080
#define IDT_PARTIAL_POOL_CONTENTS       1081
#define IDC_DOWNLOAD_CD_BURN_SOFTWARE   1082
#define IDT_RESCUE_DISK_BURN_INFO       1083
#define IDT_WIPE_MODE_INFO              1084
#define IDC_WIPE_MODE                   1085
#define IDC_SELECT                      1086
#define IDT_SYSENC_KEYS_GEN_INFO        1087
#define IDC_DISPLAY_KEYS                1088
#define IDC_PAUSE                       1089
#define IDT_WIPE_MODE                   1090
#define IDC_MORE_INFO_SYS_ENCRYPTION    1091
#define IDC_BOX_HELP_NORMAL_VOL         1092
#define IDT_STATUS                      1093
#define IDT_PROGRESS                    1094
#define IDT_SYSENC_DRIVE_ANALYSIS_INFO  1095
#define IDC_SYSENC_NORMAL               1096
#define IDC_SYSENC_HIDDEN               1097
#define IDC_BOX_HELP_SYSENC_NORMAL      1098
#define IDC_HIDDEN_SYSENC_INFO_LINK     1099
#define IDT_PASS                        1100
#define IDC_DEVICE_TRANSFORM_MODE_FORMAT 1101
#define IDC_DEVICE_TRANSFORM_MODE_INPLACE 1102
#define IDC_DRIVE_LETTER_LIST           1103
#define IDT_DRIVE_LETTER                1104
#define IDC_LINK_PIM_INFO               1105
#define IDC_SHOW_PIM                    1106
#define IDC_TB                          1107

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        134
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1108
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> veracrypt_1.26.7.orig.tar.bz2: src/Format/Resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Format.rc
//
#define IDR_FORMAT_TLB                  1
#define IDD_VOL_CREATION_WIZARD_DLG     101
#define IDD_CIPHER_PAGE_DLG             102
#define IDD_SIZE_PAGE_DLG               103
#define IDD_PASSWORD_PAGE_DLG           104
#define IDD_VOLUME_LOCATION_PAGE_DLG    105
#define IDD_FORMAT_PAGE_DLG             106
#define IDD_INTRO_PAGE_DLG              107
#define IDD_INFO_PAGE_DLG               108
#define IDD_HIDVOL_HOST_FILL_PAGE_DLG   109
#define IDD_HIDDEN_VOL_WIZARD_MODE_PAGE_DLG 110
#define IDD_PASSWORD_ENTRY_PAGE_DLG     111
#define IDS_UACSTRING_FMT               112
#define IDD_VOLUME_TYPE_PAGE_DLG        113
#define IDR_FORMAT_RSRC_HEADER          114
#define IDD_SYSENC_SPAN_PAGE_DLG        115
#define IDB_WIZARD                      116
#define IDD_SYSENC_RESCUE_DISK_CREATION_DLG 117
#define IDD_SYSENC_COLLECTING_RANDOM_DATA_DLG 118
#define IDD_SYSENC_MULTI_BOOT_MODE_PAGE_DLG 119
#define IDD_SYSENC_RESCUE_DISK_BURN_PAGE_DLG 120
#define IDD_SYSENC_WIPE_MODE_PAGE_DLG   121
#define IDD_INPLACE_ENCRYPTION_PAGE_DLG 122
#define IDD_SYSENC_KEYS_GEN_PAGE_DLG    123
#define IDD_UNIVERSAL_DUAL_CHOICE_PAGE_DLG 124
#define IDD_SYSENC_DRIVE_ANALYSIS_PAGE_DLG 125
#define IDD_SYSENC_TYPE_PAGE_DLG        126
#define IDD_SYSENC_HIDDEN_OS_REQ_CHECK_PAGE_DLG 127
#define IDD_DEVICE_WIPE_PAGE_DLG        128
#define IDD_DEVICE_WIPE_MODE_PAGE_DLG   129
#define IDD_DEVICE_TRANSFORM_MODE_DLG   130
#define IDD_EXPANDED_LIST_SELECT_PAGE_DLG 131
#define IDD_DRIVE_LETTER_SELECTION_PAGE 132
#define IDD_PIM_PAGE_DLG                133
#define IDC_BOX_TITLE                   1000
#define IDC_RESCUE_DISK_ISO_PATH        1001
#define IDC_COMBO_BOX                   1002
#define IDC_BOX_HELP                    1003
#define IDC_PASSWORD                    1004
#define IDC_BROWSE                      1005
#define IDC_BOX_HELP2                   1006
#define IDC_COMBO_BOX_HASH              1007
#define IDC_COMBO_BOX_HASH_ALGO         1008
#define IDC_SPACE_LEFT                  1009
#define IDC_VERIFY                      1010
#define IDC_KB                          1011
#define IDC_NO_HISTORY                  1012
#define IDC_MB                          1013
#define IDC_PROGRESS_BAR                1014
#define IDC_GB                          1015
#define IDC_ABORT_BUTTON                1016
#define IDC_HEADER_KEY                  1017
#define IDC_LIST_BOX                    1018
#define IDC_DISK_KEY                    1019
#define IDC_RANDOM_BYTES                1020
#define IDC_CIPHER_TEST                 1021
#define IDC_BENCHMARK                   1022
#define IDC_QUICKFORMAT                 1023
#define IDC_BYTESWRITTEN                1024
#define IDC_WRITESPEED                  1025
#define IDC_KEY_FILES                   1026
#define IDC_TIMEREMAIN                  1027
#define IDC_CLUSTERSIZE                 1028
#define IDC_FILESYS                     1029
#define IDC_SHOW_KEYS                   1030
#define IDC_STD_VOL                     1031
#define IDC_HIDDEN_VOL                  1032
#define IDC_HIDDEN_VOL_HELP             1033
#define IDC_OPEN_OUTER_VOLUME           1034
#define IDC_HIDVOL_WIZ_MODE_FULL        1035
#define IDC_HIDVOL_WIZ_MODE_DIRECT      1036
#define IDC_PASSWORD_DIRECT             1037
#define IDC_SIZEBOX                     1038
#define IDC_SELECT_VOLUME_LOCATION      1039
#define IDC_NEXT                        1040
#define IDC_PREV                        1041
#define IDT_ENCRYPTION_ALGO             1042
#define IDT_HASH_ALGO                   1043
#define IDT_FORMAT_OPTIONS              1044
#define IDT_FILESYSTEM                  1045
#define IDT_CLUSTER                     1046
#define IDT_RANDOM_POOL                 1047
#define IDT_HEADER_KEY                  1048
#define IDT_MASTER_KEY                  1049
#define IDT_DONE                        1050
#define IDT_SPEED                       1051
#define IDT_LEFT                        1052
#define IDT_CONFIRM                     1053
#define IDT_PASSWORD                    1054
#define IDC_SHOW_PASSWORD_SINGLE        1055
#define IDC_SHOW_PASSWORD               1056
#define IDC_LINK_MORE_INFO_ABOUT_CIPHER 1057
#define IDC_LINK_HASH_INFO              1058
#define IDC_POS_BOX                     1059
#define IDC_BITMAP_WIZARD               1060
#define IDC_FILE_CONTAINER              1061
#define IDC_NONSYS_DEVICE               1062
#define IDC_SYS_DEVICE                  1063
#define IDT_FILE_CONTAINER              1064
#define IDT_NON_SYS_DEVICE              1065
#define IDT_SYS_DEVICE                  1066
#define IDC_WHOLE_SYS_DRIVE             1067
#define IDC_SYS_PARTITION               1068
#define IDT_WHOLE_SYS_DRIVE             1069
#define IDT_SYS_PARTITION               1070
#define IDT_RESCUE_DISK_INFO            1071
#define IDC_MORE_INFO                   1072
#define IDC_MORE_INFO_ON_SYS_ENCRYPTION 1073
#define IDT_COLLECTING_RANDOM_DATA_NOTE 1074
#define IDC_MORE_INFO_ON_CONTAINERS     1075
#define IDC_SINGLE_BOOT                 1076
#define IDC_MULTI_BOOT                  1077
#define IDT_MULTI_BOOT                  1078
#define IDT_SINGLE_BOOT                 1079
#define IDC_SYS_POOL_CONTENTS           1080
#define IDT_PARTIAL_POOL_CONTENTS       1081
#define IDC_DOWNLOAD_CD_BURN_SOFTWARE   1082
#define IDT_RESCUE_DISK_BURN_INFO       1083
#define IDT_WIPE_MODE_INFO              1084
#define IDC_WIPE_MODE                   1085
#define IDC_SELECT                      1086
#define IDT_SYSENC_KEYS_GEN_INFO        1087
#define IDC_DISPLAY_KEYS                1088
#define IDC_PAUSE                       1089
#define IDT_WIPE_MODE                   1090
#define IDC_MORE_INFO_SYS_ENCRYPTION    1091
#define IDC_BOX_HELP_NORMAL_VOL         1092
#define IDT_STATUS                      1093
#define IDT_PROGRESS                    1094
#define IDT_SYSENC_DRIVE_ANALYSIS_INFO  1095
#define IDC_SYSENC_NORMAL               1096
#define IDC_SYSENC_HIDDEN               1097
#define IDC_BOX_HELP_SYSENC_NORMAL      1098
#define IDC_HIDDEN_SYSENC_INFO_LINK     1099
#define IDT_PASS                        1100
#define IDC_DEVICE_TRANSFORM_MODE_FORMAT 1101
#define IDC_DEVICE_TRANSFORM_MODE_INPLACE 1102
#define IDC_DRIVE_LETTER_LIST           1103
#define IDT_DRIVE_LETTER                1104
#define IDC_LINK_PIM_INFO               1105
#define IDC_SHOW_PIM                    1106
#define IDC_TB                          1107
#define IDC_SKIP_RESCUE_VERIFICATION    1108
#define SPARSE_FILE                     1109
#define IDC_FORMAT_TYPE                 1110

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        134
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1111
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
